@@ -1,31 +1,47 @@
 package Perl::Dist::WiX::IconArray;
 
-####################################################################
-# Perl::Dist::WiX::IconArray - Object that represents a list of <Icon> tags.
-#
-# Copyright 2009 Curtis Jewell
-#
-# License is the same as perl. See Wix.pm for details.
-#
+=pod
+
+=head1 NAME
+
+Perl::Dist::WiX::IconArray - A list of <Icon> tags.
+
+=head1 VERSION
+
+This document describes Perl::Dist::WiX::IconArray version 1.102.
+
+=head1 DESCRIPTION
+
+	# TODO: Document
+
+=head1 SYNOPSIS
+
+	# TODO: Document
+
+=head1 INTERFACE
+
+	# TODO: Document
+	
+=cut
+
 use 5.008001;
-use Moose;
-use MooseX::AttributeHelpers;
+use Moose 0.90;
 use Params::Util qw( _STRING   );
 use File::Spec::Functions qw( splitpath );
 require Perl::Dist::WiX::Tag::Icon;
 
-our $VERSION = '1.101_001';
-$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
+our $VERSION = '1.102_100';
+$VERSION =~ s/_//ms;
 
 has _icon => (
-	metaclass => 'Collection::Array',
+	traits    => ['Array'],
 	is        => 'rw',
 	isa       => 'ArrayRef[Perl::Dist::WiX::Tag::Icon]',
 	default   => sub { [] },
-	provides  => {
-		'push'     => '_push_icon',
-		'count'    => '_count_icons',
-		'elements' => '_get_icon_array',
+	handles  => {
+		'_push_icon'      => 'push',
+		'_count_icons'    => 'count',
+		'_get_icon_array' => 'elements',
 	},
 );
 
@@ -100,6 +116,7 @@ sub add_icon {
 #   Id of icon.
 
 sub search_icon {
+	## no critic (ProhibitExplicitReturnUndef)
 	my ( $self, $pathname_icon, $target_type ) = @_;
 
 	# Check parameters
@@ -162,3 +179,48 @@ no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
+
+__END__
+
+=pod
+
+=head1 DIAGNOSTICS
+
+See L<Perl::Dist::WiX::Diagnostics|Perl::Dist::WiX::Diagnostics> for a list of
+exceptions that this module can throw.
+
+=head1 BUGS AND LIMITATIONS (SUPPORT)
+
+Bugs should be reported via: 
+
+1) The CPAN bug tracker at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Dist-WiX>
+if you have an account there.
+
+2) Email to E<lt>bug-Perl-Dist-WiX@rt.cpan.orgE<gt> if you do not.
+
+For other issues, contact the topmost author.
+
+=head1 AUTHORS
+
+Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
+
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+
+=head1 SEE ALSO
+
+L<Perl::Dist::WiX|Perl::Dist::WiX>, 
+L<http://ali.as/>, L<http://csjewell.comyr.com/perl/>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2009 - 2010 Curtis Jewell.
+
+Copyright 2008 - 2009 Adam Kennedy.
+
+This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
+
+The full text of the license can be found in the
+LICENSE file included with this distribution.
+
+=cut
