@@ -1,14 +1,5 @@
 package Perl::Dist::WiX::Tag::Directory;
 
-#####################################################################
-# Perl::Dist::WiX::Tag::Directory - Extends <Directory> tags to make them
-# easily searchable.
-#
-# Copyright 2009 Curtis Jewell
-#
-# License is the same as perl. See WiX.pm for details.
-#
-
 use 5.008001;
 use Moose;
 
@@ -19,7 +10,7 @@ use Params::Util qw( _STRING );
 use Digest::CRC qw( crc32_base64 );
 require Perl::Dist::WiX::Exceptions;
 
-our $VERSION = '1.101_001';
+our $VERSION = '1.102';
 $VERSION =~ s/_//ms;
 
 extends 'WiX3::XML::Directory';
@@ -79,10 +70,12 @@ sub get_directory_object {
 		return $return if defined $return;
 	}
 
+	## no critic (ProhibitExplicitReturnUndef)
 	return undef;
 } ## end sub get_directory_object
 
 sub search_dir {
+	## no critic (ProhibitExplicitReturnUndef)
 	my $self = shift;
 	my %args;
 
@@ -162,6 +155,7 @@ sub _add_directory_recursive {
 	# Should not happen, but checking to make sure we bottom out,
 	# rather than going into infinite recursion.
 	if ( length $path_to_find < 4 ) {
+		## no critic (ProhibitExplicitReturnUndef)
 		return undef;
 	}
 
@@ -217,7 +211,7 @@ Perl::Dist::WiX::Tag::Directory - <Directory> tag that knows how to search its c
 
 	my $ref_tag = Perl::Dist::WiX::Tag::Directory->new(
 		id => 'Perl'
-		# TODO.
+		# TODO: Finish documenting
 	);
 
 	# Parameters can be passed as a hash, or a hashref.
@@ -268,7 +262,7 @@ An undefined value is returned if no object with that ID could be found.
 
 =head2 search_dir
 
-TODO
+TODO: Document
 
 =head2 add_directories_id
 
@@ -295,7 +289,7 @@ L<http://wix.sourceforge.net/manual-wix3/wix_xsd_directory.htm>,
 
 =head1 COPYRIGHT
 
-Copyright 2009 Curtis Jewell.
+Copyright 2009 - 2010 Curtis Jewell.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
