@@ -1,14 +1,5 @@
 package Perl::Dist::WiX::Tag::DirectoryRef;
 
-#####################################################################
-# Perl::Dist::WiX::Tag::DirectoryRef - Extends <DirectoryRef> tags to make them
-# easily searchable.
-#
-# Copyright 2009 Curtis Jewell
-#
-# License is the same as perl. See WiX.pm for details.
-#
-
 use 5.008001;
 use Moose;
 use MooseX::Types::Moose qw( Str );
@@ -16,7 +7,7 @@ use File::Spec::Functions qw( catdir abs2rel );
 use Params::Util qw( _STRING _INSTANCE );
 require Perl::Dist::WiX::Tag::Directory;
 
-our $VERSION = '1.101_001';
+our $VERSION = '1.102_100';
 $VERSION =~ s/_//ms;
 
 extends 'WiX3::XML::DirectoryRef';
@@ -38,10 +29,12 @@ sub get_directory_object {
 		return $return if defined $return;
 	}
 
+	## no critic (ProhibitExplicitReturnUndef)
 	return undef;
 } ## end sub get_directory_object
 
 sub search_dir {
+	## no critic (ProhibitExplicitReturnUndef)
 	my $self = shift;
 	my %args;
 
@@ -51,8 +44,8 @@ sub search_dir {
 		%args = @_;
 	} else {
 
-#		print "Argument problem\n";
-		# Throw error.
+		# TODO: Throw error.
+		PDWiX->throw('Parameters passed to search_dir not a hash or hashref.');
 	}
 
 	# Set defaults for parameters.
@@ -67,7 +60,6 @@ sub search_dir {
 
 	return undef unless defined $path;
 
-# TODO: Make trace_line work.
 #	$self->trace_line( 3, "Looking for $path_to_find\n" );
 #	$self->trace_line( 4, "  in:      $path.\n" );
 #	$self->trace_line( 5, "  descend: $descend exact: $exact.\n" );
@@ -76,7 +68,6 @@ sub search_dir {
 	if ( ( defined $path ) && ( $path_to_find eq $path ) ) {
 
 #		$self->trace_line( 4, "Found $path.\n" );
-#print "Found $path.\n" ;
 		return $self;
 	}
 
@@ -121,6 +112,7 @@ sub _add_directory_recursive {
 	# Should not happen, but checking to make sure we bottom out,
 	# rather than going into infinite recursion.
 	if ( length $path_to_find < 4 ) {
+		## no critic (ProhibitExplicitReturnUndef)
 		return undef;
 	}
 
@@ -180,7 +172,7 @@ Perl::Dist::WiX::Tag::DirectoryRef - <DirectoryRef> tag that knows how to search
 
 	my $ref_tag = Perl::Dist::WiX::Tag::DirectoryRef->new(
 		id => 'Perl'
-		# TODO.
+		# TODO: Document
 	);
 
 	# Parameters can be passed as a hash, or a hashref.
@@ -261,7 +253,7 @@ L<http://wix.sourceforge.net/manual-wix3/wix_xsd_directoryref.htm>,
 
 =head1 COPYRIGHT
 
-Copyright 2009 Curtis Jewell.
+Copyright 2009 - 2010 Curtis Jewell.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
